==> HilbertVis_1.8.0.zip: HilbertVis/doc/HilbertVis.R <==
###################################################
### chunk number 1: setSeed
###################################################
#line 44 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
set.seed(271828)


###################################################
### chunk number 2: 
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
library( HilbertVis )
vec <- makeRandomTestData( )


###################################################
### chunk number 3: 
###################################################
#line 56 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
length(vec)


###################################################
### chunk number 4: plotLongVector
###################################################
#line 78 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
plotLongVector( vec )


###################################################
### chunk number 5: zoomIn
###################################################
#line 97 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
start <- 1500000
plotLongVector( vec[ start + 0:100000 ], offset=start )


###################################################
### chunk number 6: HilbertCurves
###################################################
#line 179 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
library( grid )
pushViewport( viewport( layout=grid.layout( 2, 2 ) ) )
for( i in 1:4 ) {
   pushViewport( viewport( 
       layout.pos.row=1+(i-1)%/%2, layout.pos.col=1+(i-1)%%2 ) )
   plotHilbertCurve( i, new.page=FALSE )
   popViewport( )
}   


###################################################
### chunk number 7: 
###################################################
#line 192 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
hMat <- hilbertImage( vec )


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 205 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## showHilbertImage( hMat ) 


###################################################
### chunk number 9: HilbertTest
###################################################
#line 208 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
show( showHilbertImage( hMat ) )


###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 219 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## showHilbertImage( hMat, mode="EBImage" )


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 238 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## library( HilbertVisGUI )


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 242 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## hilbertDisplay( vec )


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 278 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## dumpDataInsteadOfPlotting <- function( data, info ) {
##    str( data )
##    print( info )
## }
## hilbertDisplay( vec, plotFunc=dumpDataInsteadOfPlotting )


###################################################
### chunk number 14: 
###################################################
#line 321 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
vec2 <- vec
vec2[ 7000000 : 8000000 ] <- vec[ 7010000 : 8010000 ]


###################################################
### chunk number 15:  eval=FALSE
###################################################
## #line 328 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## hilbertDisplay( vec, vec2 )


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 347 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
## hilbertDisplayThreeChannel( 
##    vec / max(vec), vec2 / max(vec), rep( 0, length(vec) ) )


###################################################
### chunk number 17: 
###################################################
#line 439 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpgRygbW/R.INSTALL5763eca/HilbertVis/inst/doc/HilbertVis.Rnw"
sessionInfo()

==> HilbertVis_1.10.0.zip: HilbertVis/doc/HilbertVis.R <==
###################################################
### chunk number 1: setSeed
###################################################
#line 44 "HilbertVis.Rnw"
set.seed(271828)


###################################################
### chunk number 2: 
###################################################
#line 50 "HilbertVis.Rnw"
library( HilbertVis )
vec <- makeRandomTestData( )


###################################################
### chunk number 3: 
###################################################
#line 56 "HilbertVis.Rnw"
length(vec)


###################################################
### chunk number 4: plotLongVector
###################################################
#line 78 "HilbertVis.Rnw"
plotLongVector( vec )


###################################################
### chunk number 5: zoomIn
###################################################
#line 97 "HilbertVis.Rnw"
start <- 1500000
plotLongVector( vec[ start + 0:100000 ], offset=start )


###################################################
### chunk number 6: HilbertCurves
###################################################
#line 179 "HilbertVis.Rnw"
library( grid )
pushViewport( viewport( layout=grid.layout( 2, 2 ) ) )
for( i in 1:4 ) {
   pushViewport( viewport( 
       layout.pos.row=1+(i-1)%/%2, layout.pos.col=1+(i-1)%%2 ) )
   plotHilbertCurve( i, new.page=FALSE )
   popViewport( )
}   


###################################################
### chunk number 7: 
###################################################
#line 192 "HilbertVis.Rnw"
hMat <- hilbertImage( vec )


###################################################
### chunk number 8:  eval=FALSE
###################################################
## #line 205 "HilbertVis.Rnw"
## showHilbertImage( hMat ) 


###################################################
### chunk number 9: HilbertTest
###################################################
#line 208 "HilbertVis.Rnw"
show( showHilbertImage( hMat ) )


###################################################
### chunk number 10:  eval=FALSE
###################################################
## #line 219 "HilbertVis.Rnw"
## showHilbertImage( hMat, mode="EBImage" )


###################################################
### chunk number 11:  eval=FALSE
###################################################
## #line 238 "HilbertVis.Rnw"
## library( HilbertVisGUI )


###################################################
### chunk number 12:  eval=FALSE
###################################################
## #line 242 "HilbertVis.Rnw"
## hilbertDisplay( vec )


###################################################
### chunk number 13:  eval=FALSE
###################################################
## #line 278 "HilbertVis.Rnw"
## dumpDataInsteadOfPlotting <- function( data, info ) {
##    str( data )
##    print( info )
## }
## hilbertDisplay( vec, plotFunc=dumpDataInsteadOfPlotting )


###################################################
### chunk number 14: 
###################################################
#line 321 "HilbertVis.Rnw"
vec2 <- vec
vec2[ 7000000 : 8000000 ] <- vec[ 7010000 : 8010000 ]


###################################################
### chunk number 15:  eval=FALSE
###################################################
## #line 328 "HilbertVis.Rnw"
## hilbertDisplay( vec, vec2 )


###################################################
### chunk number 16:  eval=FALSE
###################################################
## #line 347 "HilbertVis.Rnw"
## hilbertDisplayThreeChannel( 
##    vec / max(vec), vec2 / max(vec), rep( 0, length(vec) ) )


###################################################
### chunk number 17: 
###################################################
#line 439 "HilbertVis.Rnw"
sessionInfo()
